@@ -459,6 +459,9 @@ execute_sql_string(const char *sql, const char *filename)
 				QueryDesc  *qdesc;
 
 				qdesc = CreateQueryDesc((PlannedStmt *) stmt,
+#if PG_MAJOR_VERSION >= 1800
+										NULL,
+#endif
 										sql,
 										GetActiveSnapshot(), NULL,
 										dest, NULL,
@@ -469,7 +472,7 @@ execute_sql_string(const char *sql, const char *filename)
 
 				ExecutorStart(qdesc, 0);
 				ExecutorRun(qdesc, ForwardScanDirection, 0
-#if PG_MAJOR_VERSION >= 1000
+#if PG_MAJOR_VERSION >= 1000 && PG_MAJOR_VERSION < 1800
 					, true
 #endif
 				);
